@@ -21,9 +21,6 @@ def call_argparse():
             epilog='source: https://github.com/Saverio976/NorMatrix')
     parser.add_argument('paths', metavar='paths', nargs='*',
             help='list of path to check (default: the current working directory)')
-    parser.add_argument('--tests-run', action='store_const', dest='action',
-            const='tests', default='norm',
-            help='if you want to execute the tests (default: execute the norm checker)')
     parser.add_argument('--no-operators-pluggin', action='store_const',
             dest='plug_operator_activ', const='no', default='yes',
             help='remove the operators pluggin (because it print some false positiv for now)')
@@ -56,26 +53,31 @@ def check_norm_path(pwd: str, plug_operator_activ: bool) -> int:
         color.print_color("red", f"DUMB BRO ({NB_ERROR} error{'' if NB_ERROR == 0 else 's'})")
         return NB_ERROR
 
-def switch_between_status(result):
-    if result.action == 'tests':
-        try:
-            from tests.fn_tests import tests
-            exit(tests.main())
-        except ModuleNotFoundError:
-            print("You cannot perform this action")
-            exit(1)
-    if result.action == 'norm':
-        ret_code = 0
-        for path in result.paths:
-            if check_norm_path(path, result.plug_operator_activ == 'yes') != 0:
-                ret_code += 1
-        if ret_code != 0:
-            if len(result.paths) == 1:
-                exit(1)
-            print(f'\nYou Have {ret_code} folder that dont respect the norm')
-            exit(1)
-        exit(0)
+def execute_tests():
+    print(__file__)
+    print(os.getcwd())
+    dirr = os.path.dirname(__file__)
+    dirr = dirr.split("/")
+    dirr = os.path.join("/", *dirr[:-3])
+    os.chdir(dirr)
+    print(os.getcwd())
+    try:
+        from test.fn_tests import tests
+        exit(tests.main())
+    except ModuleNotFoundError as e:
+        print(f"You cannot perform this action: {e}")
+        exit(1)
 
 def main():
     args = call_argparse()
-    switch_between_status(args)
+    result = args
+    ret_code = 0
+    for path in result.paths:
+        if check_norm_path(path, result.plug_operator_activ == 'yes') != 0:
+            ret_code += 1
+    if ret_code != 0:
+        if len(result.paths) == 1:
+            exit(1)
+        print(f'\nYou Have {ret_code} folder that dont respect the norm')
+        exit(1)
+    exit(0)
